"""
File with all constants
"""

BASE_URL = "https://www.wolf-smartset.com/portal"

SESSION_ID = 'SessionId'

GUI_ID_CHANGED = 'GuiIdChanged'

BUNDLE_ID = 'BundleId'

BUNDLE = 'IsSubBundle'

VALUE_ID_LIST = 'ValueIdList'

ID = 'Id'

SYSTEM_ID = 'SystemId'

TAB_VIEWS = 'TabViews'

MENU_ITEMS = 'MenuItems'

GATEWAY_ID = "GatewayId"

LAST_ACCESS = "LastAccess"

TIMESTAMP = "Timestamp"

ERROR_CODE = "ErrorCode"

ERROR_TYPE = "ErrorType"

ERROR_READ_PARAMETER = 'internal msg: ReadParameterValues error'

ERROR_MESSAGE = 'Message'

NAME = 'Name'

PERCENTAGE = '%'

HOUR = 'Std'

BAR = 'bar'

CELSIUS_TEMPERATURE = '°C'

VALUES = 'Values'

STATE = 'State'

LIST_ITEMS = 'ListItems'

DISPLAY_TEXT = 'DisplayText'

VALUE = 'Value'

PARAMETER_ID = 'ParameterId'

PARAMETER_DESCRIPTORS = 'ParameterDescriptors'

UNIT = 'Unit'

TAB_NAME = 'TabName'

VALUE_ID = 'ValueId'
